Draw a quadratic Bezier curve or quadratic Bezier spline
(multiple quadratic Bezier curves
strung together).
Usage
grid.quad(...)
quadGrob(x, y, default.units="npc",
open=TRUE, stepFn=nSteps(100), gp=gpar(), name=NULL)
Arguments
x, y
Locations of control points. There should be three,
or five (or four if not open), or seven (or eight), etc.
Locations can be numeric or grid"unit" objects.
default.units
The coordinate system to use if control point
locations are just numeric.
open
Whether to reuse the first control point as the last
control point. If closed, the shape may also be filled.
stepFn
A function to generate values of t at which the
curve will be evaluated for drawing. The default is 100 equal-sized
steps from 0 to 1. This function is called for each Bezier curve
within
the Bezier spline, with arguments x,
y (the control points), and range (indicating the
range of t to generate values for).
gp
A grid"gpar" object, as produced by
gpar(), or NULL.